@@ -1,12 +1,12 @@
 """
 DynamoDB Models for PynamoDB
 """
-
+import json
 import time
 import six
 import copy
-import collections
 import logging
+import collections
 from six import with_metaclass
 from .exceptions import DoesNotExist, TableDoesNotExist
 from .throttle import NoThrottle
@@ -15,6 +15,7 @@ from .connection.base import MetaTable
 from .connection.table import TableConnection
 from .connection.util import pythonic
 from .types import HASH, RANGE
+from pynamodb.compat import NullHandler, OrderedDict
 from pynamodb.indexes import Index, GlobalSecondaryIndex
 from pynamodb.constants import (
     ATTR_TYPE_MAP, ATTR_DEFINITIONS, ATTR_NAME, ATTR_TYPE, KEY_SCHEMA,
@@ -31,7 +32,7 @@ from pynamodb.constants import (
 
 
 log = logging.getLogger(__name__)
-log.addHandler(logging.NullHandler())
+log.addHandler(NullHandler())
 
 
 class ModelContextManager(object):
@@ -171,8 +172,8 @@ class AttributeDict(collections.MutableMapping):
     A dictionary that stores attributes by two keys
     """
     def __init__(self, *args, **kwargs):
-        self._values = collections.OrderedDict()
-        self._alt_values = collections.OrderedDict()
+        self._values = OrderedDict()
+        self._alt_values = OrderedDict()
         self.update(dict(*args, **kwargs))
 
     def __getitem__(self, key):
@@ -222,7 +223,7 @@ class Model(with_metaclass(MetaModel)):
         :param range_key: Only required if the table has a range key attribute.
         :param attrs: A dictionary of attributes to set on this object.
         """
-        self.attribute_values = collections.OrderedDict()
+        self.attribute_values = OrderedDict()
         self._set_defaults()
         if hash_key:
             attrs[self._get_meta_data().hash_keyname] = hash_key
@@ -317,7 +318,7 @@ class Model(with_metaclass(MetaModel)):
         :param action: The action to take if this item already exists.
             See: http://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_UpdateItem.html#DDB-UpdateItem-request-AttributeUpdate
         """
-        args, kwargs = self._get_save_args()
+        args, kwargs = self._get_save_args(null_check=False)
         if len(expected_values):
             kwargs.update(expected=self._build_expected_values(expected_values, UPDATE_FILTER_OPERATOR_MAP))
         attribute_cls = None
@@ -418,7 +419,7 @@ class Model(with_metaclass(MetaModel)):
         hash_key_attr = cls._get_attributes().get(hash_keyname)
         hash_key = hash_key_attr.deserialize(hash_key)
         args = (hash_key,)
-        kwargs = collections.OrderedDict()
+        kwargs = OrderedDict()
         if range_keyname:
             range_key_attr = cls._get_attributes().get(range_keyname)
             range_key_type = cls._get_meta_data().get_attribute_type(range_keyname)
@@ -562,6 +563,13 @@ class Model(with_metaclass(MetaModel)):
         """
         return cls._get_connection().delete_table()
 
+    @classmethod
+    def describe_table(cls):
+        """
+        Returns the result of a DescribeTable operation on this model's table
+        """
+        return cls._get_connection().describe_table()
+
     @classmethod
     def create_table(cls, wait=False, read_capacity_units=None, write_capacity_units=None):
         """
@@ -605,7 +613,53 @@ class Model(with_metaclass(MetaModel)):
                 else:
                     raise ValueError("No TableStatus returned for table")
 
+    @classmethod
+    def dumps(cls):
+        """
+        Returns a JSON representation of this model's table
+        """
+        return json.dumps([item._get_json() for item in cls.scan()])
+
+    @classmethod
+    def dump(cls, filename):
+        """
+        Writes the contents of this model's table as JSON to the given filename
+        """
+        with open(filename, 'w') as out:
+            out.write(cls.dumps())
+
+    @classmethod
+    def loads(cls, data):
+        content = json.loads(data)
+        with cls.batch_write() as batch:
+            for item_data in content:
+                item = cls._from_data(item_data)
+                batch.save(item)
+
+    @classmethod
+    def load(cls, filename):
+        with open(filename, 'r') as inf:
+            cls.loads(inf.read())
+
     # Private API below
+    @classmethod
+    def _from_data(cls, data):
+        """
+        Reconstructs a model object from JSON.
+        """
+        hash_key, attrs = data
+        range_key = attrs.pop('range_key', None)
+        attributes = attrs.pop(pythonic(ATTRIBUTES))
+        if range_key is not None:
+            range_keyname = cls._get_meta_data().range_keyname
+            range_keytype = cls._get_meta_data().get_attribute_type(range_keyname)
+            attributes[range_keyname] = {
+                range_keytype: range_key
+            }
+        item = cls(hash_key)
+        item._deserialize(attributes)
+        return item
+
     @classmethod
     def _build_expected_values(cls, expected_values, operator_map=None):
         """
@@ -613,7 +667,7 @@ class Model(with_metaclass(MetaModel)):
 
         :param expected_values: A list of expected values
         """
-        expected_values_result = collections.OrderedDict()
+        expected_values_result = OrderedDict()
         attributes = cls._get_attributes()
         filters = {}
         for attr_name, attr_value in expected_values.items():
@@ -654,9 +708,11 @@ class Model(with_metaclass(MetaModel)):
                         condition = {
                             COMPARISON_OPERATOR: operator_map.get(token),
                             ATTR_VALUE_LIST: [
-                                {
-                                    ATTR_TYPE_MAP[attribute_class.attr_type]: attribute_class.serialize(val) for val in value
-                                }
+                                dict([
+                                    (
+                                        ATTR_TYPE_MAP[attribute_class.attr_type],
+                                        attribute_class.serialize(val)) for val in value
+                                ])
                             ]
                         }
                     expected_values_result[attributes.get(attribute).attr_name] = condition
@@ -692,8 +748,8 @@ class Model(with_metaclass(MetaModel)):
         :param non_key_operator_map: The mapping of operators used for non key attributes
         :param filters: A list of item filters
         """
-        key_conditions = collections.OrderedDict()
-        query_conditions = collections.OrderedDict()
+        key_conditions = OrderedDict()
+        query_conditions = OrderedDict()
         non_key_operator_map = non_key_operator_map or {}
         key_attribute_classes = key_attribute_classes or {}
         for attr_name, operator, value in cls._tokenize_filters(filters):
@@ -773,7 +829,7 @@ class Model(with_metaclass(MetaModel)):
                 pythonic(LOCAL_SECONDARY_INDEXES): [],
                 pythonic(ATTR_DEFINITIONS): []
             }
-            cls._index_classes = collections.OrderedDict()
+            cls._index_classes = OrderedDict()
             for item in dir(cls):
                 item_cls = getattr(getattr(cls, item), "__class__", None)
                 if item_cls is None:
@@ -820,6 +876,19 @@ class Model(with_metaclass(MetaModel)):
                     cls._attributes[item] = instance
         return cls._attributes
 
+    def _get_json(self):
+        """
+        Returns a Python object suitable for serialization
+        """
+        kwargs = OrderedDict()
+        serialized = self._serialize(null_check=False)
+        hash_key = serialized.get(HASH)
+        range_key = serialized.get(RANGE, None)
+        if range_key:
+            kwargs[pythonic(RANGE_KEY)] = range_key
+        kwargs[pythonic(ATTRIBUTES)] = serialized[pythonic(ATTRIBUTES)]
+        return hash_key, kwargs
+
     def _get_save_args(self, attributes=True, null_check=True):
         """
         Gets the proper *args, **kwargs for saving and retrieving this object
@@ -829,7 +898,7 @@ class Model(with_metaclass(MetaModel)):
         :param attributes: If True, then attributes are included.
         :param null_check: If True, then attributes are checked for null.
         """
-        kwargs = collections.OrderedDict()
+        kwargs = OrderedDict()
         serialized = self._serialize(null_check=null_check)
         hash_key = serialized.get(HASH)
         range_key = serialized.get(RANGE, None)
@@ -984,7 +1053,7 @@ class Model(with_metaclass(MetaModel)):
         :param null_check: If True, then attributes are checked for null
         """
         attributes = pythonic(ATTRIBUTES)
-        attrs = collections.OrderedDict({attributes: collections.OrderedDict()})
+        attrs = OrderedDict({attributes: OrderedDict()})
         for name, attr in self._get_attributes().aliased_attrs():
             value = getattr(self, name)
             if value is None:
