@@ -1,18 +1,20 @@
 """
 Test model API
 """
+import random
+import json
 import six
 import copy
-import collections
 from datetime import datetime
-from unittest import TestCase
+from pynamodb.compat import CompatTestCase as TestCase
+from pynamodb.compat import patch, MagicMock, OrderedDict
 from pynamodb.throttle import Throttle
 from pynamodb.connection.util import pythonic
 from pynamodb.exceptions import TableError
 from pynamodb.types import RANGE
 from pynamodb.constants import (
     ITEM, STRING_SHORT, ALL, KEYS_ONLY, INCLUDE, REQUEST_ITEMS, UNPROCESSED_KEYS,
-    RESPONSES, KEYS, ITEMS, LAST_EVALUATED_KEY, EXCLUSIVE_START_KEY, ATTRIBUTES
+    RESPONSES, KEYS, ITEMS, LAST_EVALUATED_KEY, EXCLUSIVE_START_KEY, ATTRIBUTES, BINARY_SHORT
 )
 from pynamodb.models import Model
 from pynamodb.indexes import (
@@ -27,18 +29,11 @@ from .data import (
     MODEL_TABLE_DATA, GET_MODEL_ITEM_DATA, SIMPLE_MODEL_TABLE_DATA,
     BATCH_GET_ITEMS, SIMPLE_BATCH_GET_ITEMS, COMPLEX_TABLE_DATA,
     COMPLEX_ITEM_DATA, INDEX_TABLE_DATA, LOCAL_INDEX_TABLE_DATA,
-    CUSTOM_ATTR_NAME_INDEX_TABLE_DATA, CUSTOM_ATTR_NAME_ITEM_DATA
+    CUSTOM_ATTR_NAME_INDEX_TABLE_DATA, CUSTOM_ATTR_NAME_ITEM_DATA,
+    BINARY_ATTR_DATA, SERIALIZED_TABLE_DATA
 )
 
 
-# Py2/3
-if six.PY3:
-    from unittest.mock import patch
-    from unittest.mock import MagicMock
-else:
-    from mock import patch
-    from mock import MagicMock
-
 PATCH_METHOD = 'botocore.operation.Operation.call'
 
 
@@ -353,7 +348,9 @@ class ModelTestCase(TestCase):
             item = UserModel('foo', 'bar')
             self.assertEqual(item.email, 'needs_email')
             self.assertEqual(item.callable_field, 42)
-            self.assertEqual(repr(item), '{0}<{1}, {2}>'.format(UserModel.Meta.table_name, item.custom_user_name, item.user_id))
+            self.assertEqual(
+                repr(item), '{0}<{1}, {2}>'.format(UserModel.Meta.table_name, item.custom_user_name, item.user_id)
+            )
             self.assertEqual(repr(UserModel._get_meta_data()), 'MetaTable<{0}>'.format('Thread'))
 
         with patch(PATCH_METHOD) as req:
@@ -639,6 +636,38 @@ class ModelTestCase(TestCase):
             }
             self.assertEqual(args, params)
 
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK({}), {
+                ATTRIBUTES: {
+                    "views": {
+                        "N": "10"
+                    }
+                }
+            }
+            # Reproduces https://github.com/jlafon/PynamoDB/issues/34
+            item.email = None
+            item.update_item('views', 10, action='add')
+            args = req.call_args[1]
+            params = {
+                'table_name': 'SimpleModel',
+                'return_values': 'ALL_NEW',
+                'key': {
+                    'user_name': {
+                        'S': 'foo'
+                    }
+                },
+                'attribute_updates': {
+                    'views': {
+                        'Action': 'ADD',
+                        'Value': {
+                            'N': '10'
+                        }
+                    }
+                },
+                'return_consumed_capacity': 'TOTAL'
+            }
+            self.assertEqual(args, params)
+
     def test_save(self):
         """
         Model.save
@@ -954,7 +983,7 @@ class ModelTestCase(TestCase):
                     user_id__begins_with='id',
                     email__contains='@',
                     picture__null=False,
-                    zip_code__between=[2,3]):
+                    zip_code__between=[2, 3]):
                 queried.append(item._serialize())
             params = {
                 'key_conditions': {
@@ -999,10 +1028,6 @@ class ModelTestCase(TestCase):
         """
         Model.scan
         """
-        with patch(PATCH_METHOD) as req:
-            req.return_value = HttpOK(), MODEL_TABLE_DATA
-            UserModel('foo', 'bar')
-
         with patch(PATCH_METHOD) as req:
             items = []
             for idx in range(10):
@@ -1234,10 +1259,6 @@ class ModelTestCase(TestCase):
         """
         Model.batch_write
         """
-        with patch(PATCH_METHOD) as req:
-            req.return_value = HttpOK(), MODEL_TABLE_DATA
-            UserModel('foo', 'bar')
-
         with patch(PATCH_METHOD) as req:
             req.return_value = HttpOK({}), {}
 
@@ -1521,7 +1542,6 @@ class ModelTestCase(TestCase):
             req.return_value = HttpOK(), LOCAL_INDEX_TABLE_DATA
             LocalIndexedModel('foo')
 
-
         schema = IndexedModel._get_indexes()
 
         expected = {
@@ -1567,6 +1587,7 @@ class ModelTestCase(TestCase):
         self.assertEqual(schema['local_secondary_indexes'][0]['projection']['NonKeyAttributes'], ['numbers'])
 
         scope_args = {'count': 0}
+
         def fake_dynamodb(obj, **kwargs):
             if scope_args['count'] == 0:
                 scope_args['count'] += 1
@@ -1579,7 +1600,7 @@ class ModelTestCase(TestCase):
 
         with patch(PATCH_METHOD, new=fake_db) as req:
             LocalIndexedModel.create_table(read_capacity_units=2, write_capacity_units=2)
-            params = collections.OrderedDict({
+            params = OrderedDict({
                 'attribute_definitions': [
                     {
                         'attribute_name': 'email', 'attribute_type': 'S'
@@ -1654,3 +1675,66 @@ class ModelTestCase(TestCase):
 
         with self.assertRaises(AttributeError):
             OldStyleModel.exists()
+
+    def test_dumps(self):
+        """
+        Model.dumps
+        """
+        with patch(PATCH_METHOD) as req:
+            items = []
+            for idx in range(10):
+                item = copy.copy(GET_MODEL_ITEM_DATA.get(ITEM))
+                item['user_id'] = {STRING_SHORT: 'id-{0}'.format(idx)}
+                item['email'] = {STRING_SHORT: 'email-{0}'.format(random.randint(0, 65536))}
+                item['picture'] = {BINARY_SHORT: BINARY_ATTR_DATA}
+                items.append(item)
+            req.return_value = HttpOK({'Items': items}), {'Items': items}
+            content = UserModel.dumps()
+            serialized_items = json.loads(content)
+            for original, new_item in zip(items, serialized_items):
+                self.assertEqual(new_item[0], original['user_name'][STRING_SHORT])
+                self.assertEqual(new_item[1][pythonic(ATTRIBUTES)]['zip_code']['N'], original['zip_code']['N'])
+                self.assertEqual(new_item[1][pythonic(ATTRIBUTES)]['email']['S'], original['email']['S'])
+                self.assertEqual(new_item[1][pythonic(ATTRIBUTES)]['picture']['B'], original['picture']['B'])
+
+    def test_loads(self):
+        """
+        Model.loads
+        """
+        with patch(PATCH_METHOD) as req:
+            req.return_value = HttpOK({}), {}
+            UserModel.loads(json.dumps(SERIALIZED_TABLE_DATA))
+
+        args = {
+            'UserModel': [
+                {
+                    'PutRequest': {
+                        'Item': {
+                            'user_id': {'S': u'id-0'},
+                            'callable_field': {'N': '42'},
+                            'user_name': {'S': u'foo'},
+                            'email': {'S': u'email-7980'},
+                            'picture': {
+                                "B": "aGVsbG8sIHdvcmxk"
+                            },
+                            'zip_code': {'N': '88030'}
+                        }
+                    }
+                },
+                {
+                    'PutRequest': {
+                        'Item': {
+                            'user_id': {'S': u'id-1'},
+                            'callable_field': {'N': '42'},
+                            'user_name': {'S': u'foo'},
+                            'email': {'S': u'email-19770'},
+                            'picture': {
+                                "B": "aGVsbG8sIHdvcmxk"
+                            },
+                            'zip_code': {'N': '88030'}
+                        }
+                    }
+                }
+            ]
+        }
+        self.assert_dict_lists_equal(req.call_args[1]['request_items']['UserModel'], args['UserModel'])
